require.config({
	urlArgs: `v=${app.version}`,
	baseUrl: "js/lib",
	paths: {
		Swiper: 'Swiper',
		'jquery-sortable': 'jquery-sortable',
		'touchSwipe': 'touchSwipe',
		'jquery': 'jquery'
	}
});

require(['Swiper', 'jquery-sortable', 'touchSwipe', 'jquery'])

require(['jquery'], function($) {
	/**
	 * 存储获取数据函数
	 * @function get 存储数据
	 * @function set 获取数据
	 */
	var store = {
		/**
		 * 存储名称为key的val数据
		 * @param {String} key 键值
		 * @param {String} val 数据
		 */
		set: function(key, val) {
			if (!val) {
				return;
			}
			try {
				var json = JSON.stringify(val);
				if (typeof JSON.parse(json) === "object") { // 验证一下是否为JSON字符串防止保存错误
					localStorage.setItem(key, json);
				}
			} catch (e) {
				return false;
			}
		},
		/**
		 * 获取名称为key的数据
		 * @param {String} key 键值
		 */
		get: function(key) {
			if (this.has(key)) {
				return JSON.parse(localStorage.getItem(key));
			}
		},
		has: function(key) {
			if (localStorage.getItem(key)) {
				return true;
			} else {
				return false;
			}
		},
		del: function(key) {
			localStorage.removeItem(key);
		}
	};

	var settingsFn = function(storage) {
		this.storage = {
			engines: "quark",
			bookcolor: "black",
			searchHistory: true
		};
		this.storage = $.extend({}, this.storage, storage);
	}
	settingsFn.prototype = {
		getJson: function() {
			return this.storage;
		},
		// 读取设置项
		get: function(key) {
			return this.storage[key];
		},
		// 设置设置项并应用
		set: function(key, val) {
			this.storage[key] = val;
			store.set("setData", this.storage);
			this.apply();
		},
		// 应用设置项
		apply: function() {
			var that = this;
			// 样式细圆
			if (that.get('styleThin')) {
				$("body").addClass('styleThin');
			}
			$('.ornament-input-group').removeAttr('style');
			// 加载LOGO
			if (that.get('logo')) {
				$(".logo").html('<img src="' + that.get('logo') + '" />');
			}
			// 夜间模式 和 壁纸
			var nightMode = {
				on: function() {
					$("body").removeClass('theme-black theme-white').addClass('theme-white');
					$("body").css("background-image", "");
					$("#nightCss").removeAttr('disabled');
				},
				off: function() {
					if (that.get('wallpaper')) {
						$("body").css("background-image", "url(" + that.get('wallpaper') + ")");
					} else {
						$("body").css("background-image", "");
					}
					$("body").removeClass('theme-black theme-white').addClass('theme-' + that
						.get('bookcolor'));
					$("#nightCss").attr('disabled', true);
				}
			};
			if (that.get('nightMode') === true) {
				nightMode.on();
			} else {
				nightMode.off();
			}
			// 删除掉VIA浏览器夜间模式的暗色支持
			$("head").on("DOMNodeInserted DOMNodeRemoved", function(evt) {
				if (evt.target.id === "via_inject_css_night") {
					if (evt.type === "DOMNodeInserted") {
						$("#via_inject_css_night").html("");
						nightMode.on();
					} else if (evt.type === "DOMNodeRemoved") {
						nightMode.off();
					}
				}
			});
			if ($("#via_inject_css_night").html("").length > 0) {
				nightMode.on();
			}
		}
	}
	var settings = new settingsFn(store.get("setData"));
	settings.apply();

	/**
	 * DOM长按事件
	 */
	$.fn.longPress = function(fn) {
		var timeout = void 0,
			$this = this,
			startPos,
			movePos,
			endPos;
		for (var i = $this.length - 1; i > -1; i--) {
			$this[i].addEventListener('contextmenu', function(e) {
				e.stopPropagation();
				e.preventDefault();
				fn();
			})
		}
	};

	/**
	 * 文件打开函数
	 * @param callback 回调函数
	 */
	var openFile = function(callback) {
		$('.openFile').remove();
		var input = $('<input class="openFile" type="file">');
		input.on("propertychange change", callback);
		$('body').append(input);
		input.click();
	}

	/**
	 * 文件上传函数
	 * @param file 文件
	 * @param callback 回调函数 
	 */
	var uploadFile = function(file, callback) {
		var imageData = new FormData();
		imageData.append("Filedata", file);
		imageData.append("file", "multipart");
		$.ajax({
			url: 'https://api.uomg.com/api/image.ali',
			type: 'POST',
			data: imageData,
			cache: false,
			contentType: false,
			processData: false,
			dataType: 'json',
			success: function(res) {
				if (res.code == 1) {
					callback.success && callback.success(res.imgurl);
				} else {
					callback.error && callback.error(res.msg);
				}
			},
			error: function() {
				callback.error && callback.error('请求失败！');
			},
			complete: function() {
				callback.complete && callback.complete();
			}
		});
	}

	/**
	 * 首页书签构建函数
	 * @function init 初始化
	 * @function bind 绑定事件
	 * @function del 删除书签
	 * @function add 添加书签
	 */
	var bookMarkFn = function(ele, options) {
		this.$ele = $(ele);
		this.options = {
			data: [ {
				"name": "知乎",
				"url": "https://www.zhihu.com",
				"icon": "icon/zhihu.png"
			}, {
				"name": "贴吧",
				"url": "https://tieba.baidu.com",
				"icon": "icon/tieba.png"
			}, {
				"name": "IT之家",
				"url": "https://m.ithome.com",
				"icon": "icon/ithome.png"
			}, {
				"name": "IP查询",
				"url": "https://www.ip138.com/",
				"icon": "img/choice/ip.png"
			},
			{
				"name": "微博",
				"url": "https://weibo.com",
				"icon": "icon/weibo.png"
			}
			
			],
		};
		this.options = $.extend({}, this.options, options);
		this.init();
	}
	bookMarkFn.prototype = {
		init: function() {
			var html = '';
			var data = this.options.data;
			for (var i = 0, l = data.length; i < l; i++) {
				html += '<div class="list" data-url="' + data[i].url +
					'"><div class="img" style="background-image:url(' + data[i].icon +
					')"></div><div class="text">' + data[i].name + "</div></div>";
			}
			this.$ele.html(html);
			this.bind();
		},
		getJson: function() {
			return this.options.data;
		},
		bind: function() {
			var that = this;
			var data = this.options.data;
			// 绑定书签长按事件
			this.$ele.longPress(function() {
				if (that.status !== "editing" && data.length > 0) {
					that.status = "editing";
					$('.logo,.ornament-input-group').css('pointer-events', 'none');
					$('.addbook').remove();
					require(['jquery-sortable'], function() {
						that.$ele.sortable({
							animation: 150,
							fallbackTolerance: 3,
							touchStartThreshold: 3,
							ghostClass: "ghost",
							onEnd: function(evt) {
								var startID = evt.oldIndex,
									endID = evt.newIndex;
								if (startID > endID) {
									data.splice(endID, 0, data[startID]);
									data.splice(startID + 1, 1);
								} else {
									data.splice(endID + 1, 0, data[
									startID]);
									data.splice(startID, 1);
								}
								store.set("bookMark", data);
							}
						});
					})
					$(document).click(function() {
						$(document).unbind("click");
						$('.logo,.ornament-input-group').css('pointer-events', '');
						$(".delbook").addClass("animation");
						$(".delbook").on('transitionend', function(evt) {
							if (evt.target !== this) {
								return;
							}
							$(".delbook").remove();
							that.$ele.sortable("destroy");
							that.status = "";
						});
					});
					var $list = that.$ele.find(".list");
					for (var i = $list.length; i > -1; i--) {
						$list.eq(i).find(".img").prepend('<div class="delbook"></div>');
					}
				}
			});
			this.$ele.on('click', function(evt) {
				if (evt.target !== this || that.status === 'editing' || $('.addbook').hasClass(
						'animation') || data.length >= 20) {
					return;
				}
				if ($('.addbook').length === 0) {
					that.$ele.append(
						'<div class="list addbook"><div class="img"><svg viewBox="0 0 1024 1024"><path class="st0" d="M673,489.2H534.8V350.9c0-12.7-10.4-23-23-23c-12.7,0-23,10.4-23,23v138.2H350.6c-12.7,0-23,10.4-23,23c0,12.7,10.4,23,23,23h138.2v138.2c0,12.7,10.4,23,23,23c12.7,0,23-10.4,23-23V535.2H673c12.7,0,23-10.4,23-23C696.1,499.5,685.7,489.2,673,489.2z" fill="#222"/></svg></div></div>'
						);
					$('.addbook').click(function() {
						// 取消书签编辑状态
						$(document).click();
						// 插入html
						choice()
						$('.addbook').remove();

					})
				} else {
					$(".addbook").addClass("animation");
					$(".addbook").remove();
				}
			});
			this.$ele.on('click', '.list', function(evt) {
				evt.stopPropagation();
				var dom = $(evt.currentTarget);
				if (that.status !== "editing") {
					var url = dom.data("url");
					if (url) {
						switch (url) {
							case "choice()":
								choice();
								break;
							default:
								location.href = url;
						}
					}
				} else {
					if (evt.target.className === "delbook") {
						that.del(dom.index());
					}
				}
			});
		},
		del: function(index) {
			var that = this;
			var data = this.options.data;
			this.$ele.css("overflow", "visible");
			var dom = this.$ele.find('.list').eq(index);
			dom.css({
				transform: "translateY(60px)",
				opacity: 0,
				transition: ".3s"
			});
			dom.on('transitionend', function(evt) {
				if (evt.target !== this) {
					return;
				}
				dom.remove();
				that.$ele.css("overflow", "hidden");
			});
			data.splice(index, 1);
			store.set("bookMark", data);
		},
		add: function(name, url, icon) {
			var data = this.options.data;
			for(let i=0; i<data.length; i++) {
				if(data[i].url === url) {
					return
				}
			}
			url = url.match(/:\/\//) ? url : "http://" + url;
			var i = data.length - 1;
			var dom = $('<div class="list" data-url="' + url +
				'"><div class="img" style="background-image:url(' + icon +
				')"></div><div class="text">' + name + '</div></div>');
			this.$ele.append(dom);
			// dom.css({
			// 	marginTop: "60px",
			// }).animate({
			// 	marginTop: 0,
			// }, 300);
			data.push({
				name: name,
				url: url,
				icon: icon
			});
			store.set("bookMark", data);
		}
	}

	/**
	 * 搜索历史构建函数
	 * @function init 初始化
	 * @function load 加载HTML
	 * @function bind 绑定事件
	 * @function add 添加历史
	 * @function empty 清空历史
	 */
	var searchHistoryFn = function(ele, options) {
		this.$ele = $(ele);
		this.options = {
			data: []
		};
		this.options = $.extend({}, this.options, options);
		this.init();
	}
	searchHistoryFn.prototype = {
		init: function() {
			this.options.data = this.options.data.slice(0, 10);
			this.load();
			this.bind();
		},
		load: function() {
			var data = this.options.data;
			var html = '';
			var l = data.length;
			for (var i = 0; i < l; i++) {
				html += '<li>' + data[i] + '</li>';
			}
			this.$ele.find('.content').html(html);
			l ? $('.emptyHistory').show() : $('.emptyHistory').hide();
		},
		bind: function() {
			var that = this;
			// 监听touch事件，防止点击后弹出或收回软键盘
			$('.emptyHistory')[0].addEventListener("touchstart", function(e) {
				e.preventDefault();
			}, false);
			$('.emptyHistory')[0].addEventListener("touchend", function(e) {
				if ($('.emptyHistory').hasClass('animation')) {
					that.empty();
				} else {
					$('.emptyHistory').addClass('animation');
				}
			}, false);
			this.$ele.click(function(evt) {
				if (evt.target.nodeName === "LI") {
					$('.search-input').val(evt.target.innerText).trigger("propertychange");
					$('.search-btn').click();
				}
			});
		},
		add: function(text) {
			var data = this.options.data;
			if (settings.get('searchHistory') === true) {
				var pos = data.indexOf(text);
				if (pos !== -1) {
					data.splice(pos, 1);
				}
				data.unshift(text);
				this.load();
				store.set("history", data);
			}
		},
		empty: function() {
			this.options.data = [];
			store.set("history", []);
			this.load();
		}
	}

	// 开始构建
	var bookMark = new bookMarkFn($('.bookmark'), {
		data: store.get("bookMark")
	})
	var searchHistory = new searchHistoryFn($('.history'), {
		data: store.get("history")
	});

	/**
	 * 更改地址栏URL参数
	 * @param {string} param 参数
	 * @param {string} value 值
	 * @param {string} url 需要更改的URL,不设置此值会使用当前链接
	 */
	var changeParam = function(param, value, url) {
		url = url || location.href;
		var reg = new RegExp("(^|)" + param + "=([^&]*)(|$)");
		var tmp = param + "=" + value;
		return url.match(reg) ? url.replace(eval(reg), tmp) : url.match("[?]") ? url + "&" + tmp : url +
			"?" + tmp;
	};

	// 更改URL，去除后面的参数
	history.replaceState(null, document.title, location.origin + location.pathname);

	// 绑定主页虚假输入框点击事件
	$(".ornament-input-group").click(function() {
		// $('body').css("pointer-events", "none");
		history.pushState(null, document.title, changeParam("page", "search"));
		// 输入框边框动画
		$('.anitInput').remove();
		var ornamentInput = $(".ornament-input-group");
		var top = ornamentInput.offset().top;
		var left = ornamentInput.offset().left;
		var anitInput = ornamentInput.clone();
		anitInput.attr('class', 'anitInput').css({
			'position': 'absolute',
			'top': top,
			'left': left,
			'width': ornamentInput.outerWidth(),
			'height': ornamentInput.outerHeight(),
			'pointer-events': 'none'
		})
		anitInput.on('transitionend', function(evt) {
			if (evt.target !== this) {
				return;
			}
			anitInput.unbind('transitionend');
			$(".input-bg").css("border-color", "var(--dark)");
			anitInput.css("opacity", "0");
		});
		$('body').append(anitInput);
		ornamentInput.css('opacity', 0);
		if ($(window).data('anitInputFn')) {
			$(window).unbind('resize', $(window).data('anitInputFn'));
		}
		var anitInputFn = function() {
			var inputBg = $('.input-bg');
			var scaleX = inputBg.outerWidth() / ornamentInput.outerWidth();
			var scaleY = inputBg.outerHeight() / ornamentInput.outerHeight();
			var translateX = inputBg.offset().left - left - (ornamentInput.outerWidth() - inputBg
				.outerWidth()) / 2;
			var translateY = inputBg.offset().top - top - (ornamentInput.outerHeight() - inputBg
				.outerHeight()) / 2;
			anitInput.css({
				'transform': 'translateX(' + translateX + 'px) translateY(' + translateY +
					'px) scale(' + scaleX + ',' + scaleY + ') translate3d(0,0,0)',
				'transition': '.3s',
				'border-color': 'var(--dark)'
			});
		}
		$(window).data('anitInputFn', anitInputFn);
		$(window).bind('resize', anitInputFn);
		// 弹出软键盘


		$(".s-temp").focus();
		// 书签动画
		$(".bookmark").addClass("animation");
		// 显示搜索页
		$(".page-search").show();
		// setTimeout(function(){
			$(".page-search").on('transitionend', function(evt) {
				if (evt.target !== this) {
					return;
				}
				$(".page-search").off('transitionend');
				// $('body').css("pointer-events", "");
			}).addClass("animation");
			$(".search-input").val("").focus();
			$(".history").show().addClass("animation");
			$(".input-bg").addClass("animation");
			$(".shortcut").addClass("animation");
		// }, 200)
	});
	
	$(".page-search").click(function(evt) {
		if (evt.target === evt.currentTarget) {
			history.go(-1);
		}
	});
	
	
	// 返回按键被点击
	window.addEventListener("popstate", function() {
		if ($('.page-search').is(":visible")) {
			$('body').css("pointer-events", "none");
			history.replaceState(null, document.title, location.origin + location.pathname);
			// 输入框边框动画
			$(window).unbind('resize', $(window).data('anitInputFn'));
			var anitInput = $('.anitInput');
			anitInput.css({
				'transform': '',
				'transition': '.3s',
				'opacity': '',
				'border-color': ''
			});
			// 书签动画
			$(".bookmark").removeClass("animation");
			// 隐藏搜索页
			$(".history").removeClass("animation");
			$(".input-bg").css("border-color", "").removeClass("animation");
			$(".shortcut").removeClass("animation");
			$(".page-search").removeClass("animation");
			$(".page-search").on('transitionend', function(evt) {
				if (evt.target !== this) {
					return;
				}
				$(".page-search").off('transitionend');
				$(".page-search").hide();
				$('.ornament-input-group').css({
					'transition': 'none',
					'opacity': ''
				});
				anitInput.remove();
				// 搜索页内容初始化
				$(".suggestion").html("");
				$(".search-btn").html("取消");
				$(".shortcut1").show();
				$(".shortcut2,.shortcut3,.empty-input").hide();
				$(".search-input").val('');
				$('.emptyHistory').removeClass('animation');
				$('body').css("pointer-events", "");
			});
		}
	}, false);

	$(".suggestion").click(function(evt) {
		if (evt.target.nodeName === "SPAN") {
			$('.search-input').focus().val($(evt.target).parent().text()).trigger("propertychange");
			return;
		} else {
			searchText(evt.target.innerText);
		}
	});
	var qs_ajax = null;
	$(".search-input").on("input propertychange", function() {
		var that = this;
		var wd = $(that).val();
		$(".shortcut1,.shortcut2,.shortcut3").hide();
		if (!wd) {
			$(".history").show();
			$(".empty-input").hide();
			$(".search-btn").html("取消");
			$(".shortcut1").show();
			$(".suggestion").hide().html('');
		} else {
			$(".history").hide();
			$(".empty-input").show();
			$(".search-btn").html(
				/^\b(((https?|ftp):\/\/)?[-a-z0-9]+(\.[-a-z0-9]+)*\.(?:com|net|org|int|edu|gov|mil|arpa|asia|biz|info|name|pro|coop|aero|museum|[a-z][a-z]|((25[0-5])|(2[0-4]\d)|(1\d\d)|([1-9]\d)|\d))\b(\/[-a-z0-9_:\@&?=+,.!\/~%\$]*)?)$/i
				.test(wd) ? "进入" : "搜索");
			var has_char = escape(wd).indexOf("%u");
			
			has_char < 0 ? $(".shortcut2").show() : $(".shortcut3").show();
			$.ajax({
				url: "https://suggestion.baidu.com/su",
				type: "GET",
				dataType: "jsonp",
				data: {
					wd: wd,
					cb: "sug"
				},
				timeout: 5000,
				jsonpCallback: "sug",
				success: function(res) {
					if ($(that).val() !== wd) {
						return;
					}
					var data = res.s;
					var isStyle = $(".suggestion").html();
					var html = "";
					for (var i = data.length; i > 0; i--) {
						var style = "";
						if (isStyle === "") {
							style = "animation: fadeInDown both .5s " + (i - 1) * 0.05 +
								's"';
						}
						html += '<li style="' + style + '"><div>' + data[i - 1].replace(wd,
							'<b>' + wd + '</b>') + "</div><span></span></li>";
					}
					$(".suggestion").show().html(html).scrollTop($(".suggestion")[0]
						.scrollHeight);
				},
				
			});
			if (qs_ajax) {
				qs_ajax.abort();
			}
			if (has_char >= 0) {
				qs_ajax = $.ajax({
					url: "https://bird.ioliu.cn/v1?url=https://quark.sm.cn/api/qs?query=" + wd +
						"&ve=4.1.0.132",
					type: "GET",
					timeout: 5000,
					success: function(res) {
						if ($(that).val() !== wd) {
							return;
						}
						var data = res.data;
						var html = '<li>快搜:</li>';
						for (var i = 0, l = data.length; i < l; i++) {
							html += '<li>' + data[i] + '</li>';
						}
						$('.shortcut3').html(html);
					}
				});
			}
		}
	});
	
	$(".empty-input").click(function() {
		$(".search-input").focus().val("").trigger("propertychange");
	});

	$(".shortcut1,.shortcut2").click(function(evt) {
		$(".search-input").focus().val($(".search-input").val() + evt.target.innerText).trigger(
			"propertychange");
	});

	$(".shortcut3").click(function(evt) {
		console.log('shortcut3')
		if (evt.target.nodeName === "LI") {
			var text = evt.target.innerText;
			var data = {
				百科: "https://baike.baidu.com/search?word=%s",
				视频: "https://m.v.qq.com/search.html?act=0&keyWord=%s",
				豆瓣: "https://m.douban.com/search/?query=%s",
				新闻: "http://m.toutiao.com/search/?&keyword=%s",
				图片: "https://m.baidu.com/sf/vsearch?pd=image_content&word=%s&tn=vsearch&atn=page",
				微博: "https://m.weibo.cn/search?containerid=100103type=1&q=%s",
				音乐: "http://m.music.migu.cn/v3/search?keyword=%s",
				知乎: "https://www.zhihu.com/search?q=%s",
				小说: "https://m.qidian.com/search?kw=%s",
				旅游: "https://h5.m.taobao.com/trip/rx-search/list/index.html?&keyword=%s",
				地图: "https://m.amap.com/search/mapview/keywords=%s",
				电视剧: "http://m.iqiyi.com/search.html?key=%s",
				股票: "https://emwap.eastmoney.com/info/search/index?t=14&k=%s",
				汽车: "https://sou.m.autohome.com.cn/zonghe?q=%s"
			}
			if (data[text]) {
				location.href = data[text].replace("%s", $(".search-input").val());
			}
		}
	});
	
	$(".search-btn").click(function() {
		console.log('search')
		var text = $(".search-input").val();
		if ($(".search-btn").text() === "进入") {
			!text.match(/^(ht|f)tp(s?):\/\//) && (text = "http://" + text);
			history.go(-1);
			location.href = text;
		} else {
			if (!text) {
				$(".search-input").blur();
				history.go(-1);
			} else {
				searchText(text);
			}
		}
	});

	$(".search-input").keydown(function(evt) {
		// 使用回车键进行搜索
		if (evt.code == "Enter" || evt.keyCode === 13) {
			$(".search-btn").click();
		}
	});



	// 识别浏览器
	var browserInfo = function() {
		if (window.via) {
			return 'via';
		} else if (window.mbrowser) {
			return 'x';
		}
	};

	// 搜索函数
	function searchText(text) {
		if (!text) {
			return;
		}
		searchHistory.add(text);
		history.go(-1);
		if (settings.get('engines') === "via") {
			window.via.searchText(text);
		} else {
			location.href = {
				// xsearch:"https://searx.rhscz.eu/search?q=%s&language=auto",
				baidu: "https://m.baidu.com/s?wd=%s",
				quark: "https://quark.sm.cn/s?q=%s",
				google: "https://www.google.com/search?q=%s",
				bing: "https://cn.bing.com/search?q=%s",
				sm: "https://m.sm.cn/s?q=%s",
				haosou: "https://m.so.com/s?q=%s",
				sogou: "https://m.sogou.com/web/searchList.jsp?keyword=%s",
				diy: settings.get('diyEngines')
			} [settings.get('engines')].replace("%s", text);
		}
	}

	//精选页面
	function choice() {
		// 构建HTML
		var data = {
				"新闻": [{
					"hl": "搜狐网",
					"shl": "懂手机更懂你",
					"img": "souhu",
					"url": "www.sohu.com"
				}, {
					"hl": "腾讯新闻",
					"shl": "手机腾讯网",
					"img": "qq",
					"url": "xw.qq.com"
				}, {
					"hl": "豆瓣新片",
					"shl": "一个神奇的社区",
					"img": "doubanxinpianbang",
					"url": "tophub.today/n/mDOvnyBoEB"
				}, {
					"hl": "网易",
					"shl": "各有态度",
					"img": "netease",
					"url": "3g.163.com"
				}],
				"热搜": [{
					"hl": "今日热榜",
					"shl": "今天发生了什么有趣的事？",
					"img": "hot",
					"url": "tophub.today"
				},{
					"hl": "贴吧热议",
					"shl": "百度贴吧 ‧ 热议榜",
					"img": "tieba",
					"url": "tophub.today/n/Om4ejxvxEN"
				},{
					"hl": "夸克热搜",
					"shl": "快讯一网打尽",
					"img": "kuakeresou",
					"url": "vt.quark.cn/blm/hot-board-599/tab?app=news&uc_biz_str=qk_enable_gesture:true%7COPT:W_ENTER_ANI@1%7COPT:TOOLBAR_STYLE@0%7COPT:W_PAGE_REFRESH@0%7COPT:BACK_BTN_STYLE@0%7COPT:IMMERSIVE@1&entry=homepage"
				}, {
					"hl": "微博热搜",
					"shl": "实时热搜动态",
					"img": "weiboresou",
					"url": "m.weibo.cn/p/index?containerid=106003type%3D25%26t%3D3%26disable_hot%3D1%26filter_type%3Drealtimehot&title=%E5%BE%AE%E5%8D%9A%E7%83%AD%E6%90%9C&show_cache_when_error=1&extparam=seat%3D1%26mi_cid%3D100103%26cate%3D10103%26pos%3D0_0%26c_type%3D30%26lcate%3D1001%26dgr%3D0%26filter_type%3Drealtimehot%26region_relas_conf%3D0%26display_time%3D1698396871%26pre_seqid%3D782655072"
				}, {
					"hl": "抖音热榜",
					"shl": "潮流话题聚焦",
					"img": "douyinrebang",
					"url": "tophub.today/n/DpQvNABoNE"
				}, {
					"hl": "B站热门",
					"shl": "泛科技媒体",
					"img": "bzhanremen",
					"url": "m.bilibili.com/ranking?uc_biz_str=OPT%3ABACK_BTN_STYLE%400%7COPT%3ATOOLBAR_STYLE%401"
				}],
				"IT": [{
					"hl": "极客公园",
					"shl": "科技智能助手",
					"img": "jikegongyuan",
					"url": "www.geekpark.net"
				}, {
					"hl": "36kr",
					"shl": "科技杂志",
					"img": "36kr",
					"url": "m.36kr.com"
				}, {
					"hl": "IT之家",
					"shl": "编程助手",
					"img": "ITzhijia",
					"url": "m.ithome.com"
				}, {
					"hl": "少数派",
					"shl": "精品应用推荐",
					"img": "shaoshupai",
					"url": "sspai.com"
				}],
				"体育": [ {
					"hl": "腾讯体育",
					"shl": "赛事直播专家",
					"img": "tengxuntiyu",
					"url": "sports.qq.com/kbsweb/qb/index.htm#//hot"
				}, {
					"hl": "央视体育",
					"shl": "权威赛事直播",
					"img": "yangshitiyu",
					"url": "tv.cctv.com/live/cctv5/m/"
				}, {
					"hl": "搜狐体育",
					"shl": "快讯赛事直播",
					"img": "souhutiyu",
					"url": "m.sohu.com/z/"
				}],
				"工具": [{
					"hl": "IP查询",
					"shl": "查询本机 ip",
					"img": "ip",
					"url": "www.ip138.com"
				},{
					"hl": "文档翻译",
					"shl": "智能翻译",
					"img": "baidu",
					"url": "fanyi.baidu.com/mtpe-individual/multimodal#/"
				}]
			},
			html =
			'<div class="page-bg"></div><div class="page-choice"><div class="page-content"><ul class="choice-ul">',
			tabHtml = '',
			contentHtml = ``;

		$.each(data, function(i, n) {
			tabHtml += "<li>" + i + "</li>";
			contentHtml += '<li class="choice-li swiper-slide">';
			for (var i = 0, l = n.length; i < l; i++) {
				contentHtml += '<a><div class="menu-item" data-url="' + n[i].url +  '" data-img="img/choice/'+ n[i].img  +'.png" data-hl="'+n[i].hl+'"><img src="img/choice/' + n[i]
					.img + '.png" /><p>' + n[i].hl + '</p><p>' + n[i].shl + '</p></div></a>';
			}
			contentHtml += '</li>';
		});
		// HTML添加到APP
		var res = '<div class="page-wrap">' + html + tabHtml +
			'<span class="active-span"></span></ul><div class="choice-swipe"><ul class="swiper-wrapper"><div style="position:absolute;text-align:center;top:50%;width:100%;margin-top:-64px;color:#444">正在加载页面中...</div></ul></div><div class="bottom-close"></div></div></div></div>'
		$('#app').append(res);
		$(".page-bg").addClass("animation");
		$(".page-choice").addClass("animation");
	
		var dom = $(".choice-ul li");
		var width = dom.width();
		$(".active-span").css("transform", "translate3d(" + (width / 2 - 9) + "px,0,0)");

		// 动画完成后加载，防止过渡动画卡顿
		$(".page-choice").on("transitionend", function(evt) {
			
			$(".page-choice").off("transitionend");
			$('.choice-swipe').find('.swiper-wrapper').html(contentHtml);
			
			$(".menu-item").each(function() {
				$(this).click(function () {
					var url = "https://" +  $(this).data('url')
					var img = $(this).data('img')
					var hl = $(this).data('hl')
					bookMark.add(hl, url, img)
					$(".page-choice").css('pointer-events', 'none').removeClass("animation");
					$(".page-bg").removeClass("animation");
					$(".page-choice").on('transitionend', function(evt) {
						if (evt.target !== this) {
							return;
						}
						$(".page-choice").remove();
						$(".page-wrap").remove();
						$(".page-bg").remove();
					});
				});
			})
			
			// 绑定事件
			var last_page = 0;

			require(['Swiper'], function(Swiper) {
				var swiper = new Swiper('.choice-swipe', {
					on: {
						slideChange: function() {
							var i = this.activeIndex;
							dom.eq(last_page).removeClass("current");
							$(".active-span").css("transform", "translate3d(" + (
								width * i + width / 2 - 9) + "px,0,0)");
							dom.eq(i).addClass("current");
							last_page = i;
						}
					}
				});

				// 绑定TAB点击事件
				$(".choice-ul").click(function(evt) {
					if (evt.target.nodeName == "LI") {
						swiper.slideTo($(evt.target).index());
					}
				});
			})

			// 绑定关闭按钮事件
			$(".bottom-close").click(function() {
				$(".page-choice").css('pointer-events', 'none').removeClass("animation");
				$(".page-bg").removeClass("animation");
				$(".page-choice").on('transitionend', function(evt) {
					if (evt.target !== this) {
						return;
					}
					$(".page-choice").remove();
					$(".page-wrap").remove();
					$(".page-bg").remove();
				});
			});

		})
	}
	

	$(".logo").click(() => {
		var browser = browserInfo();
		if (browser === 'via') {
			location.href = "folder://";
		} else if (browser === 'x') {
			location.href = "x:bm?sort=default";
		}
	}).longPress(() => {
		var data = [{
			"title": "搜索引擎",
			"type": "select",
			"value": "engines",
			"data": [ {
				"t": "夸克搜索",
				"v": "quark"
			}, {
				"t": "跟随Via浏览器",
				"v": "via"
			}, {
				"t": "百度搜索",
				"v": "baidu"
			}, {
				"t": "谷歌搜索",
				"v": "google"
			}, {
				"t": "必应搜索",
				"v": "bing"
			}, {
				"t": "神马搜索",
				"v": "sm"
			}, {
				"t": "好搜搜索",
				"v": "haosou"
			}, {
				"t": "搜狗搜索",
				"v": "sogou"
			}, {
				"t": "自定义",
				"v": "diy"
			}]
		}, {
			"title": "设置壁纸",
			"value": "wallpaper"
		}, {
			"title": "设置LOGO",
			"value": "logo"
		}, {
			"title": "恢复默认壁纸和LOGO",
			"value": "delLogo"
		}, {
			"title": "图标颜色",
			"type": "select",
			"value": "bookcolor",
			"data": [{
				"t": "深色图标",
				"v": "black"
			}, {
				"t": "浅色图标",
				"v": "white"
			}]
		}, {
			"title": "主页样式细圆",
			"type": "checkbox",
			"value": "styleThin"
		}, {
			"title": "夜间模式",
			"type": "checkbox",
			"value": "nightMode"
		}, {
			"title": "记录搜索历史",
			"type": "checkbox",
			"value": "searchHistory"
		}, {
			"type": "hr"
		}, {
			"title": "导出主页数据",
			"value": "export"
		}, {
			"title": "导入主页数据",
			"value": "import"
		}, {
			"type": "hr"
		}, {
			"title": "关于",
			"description": "当前版本：" + app.version
		}];
		var html =
			'<div class="page-settings"><div class="set-header"><div class="set-back"></div><p class="set-logo">主页设置</p></div><ul class="set-option-from">';
		for (var json of data) {
			if (json.type === 'hr') {
				html += `<li class="set-hr"></li>`;
			} else {
				html += `<li class="set-option" ${json.value ? `data-value="${json.value}"` : ''}>
							<div class="set-text">
								<p class="set-title">${json.title}</p>
								${json.description ? `<div class="set-description">${json.description}</div>` : ''}
							</div>`;
				if (json.type === 'select') {
					html += `<select class="set-select">`;
					for (var i of json.data) {
						html += `<option value="${i.v}">${i.t}</option>`;
					}
					html += `</select>`;
				} else if (json.type === 'checkbox') {
					html +=
						`<input type="checkbox" class="set-checkbox" autocomplete="off"><label></label>`;
				}
				html += `</li>`;
			}
		}
		html += '</ul></div>';
		$('#app').append(html);

		$(".page-settings").show();
		$(".page-settings").addClass('animation');

		var browser = browserInfo();
		if (browser !== 'via') { // 只有VIA浏览器才能显示
			$('option[value=via]').hide();
		}

		$(".set-option .set-select").map(function() {
			$(this).val(settings.get($(this).parent().data('value')));
		});

		$(".set-option .set-checkbox").map(function() {
			$(this).prop("checked", settings.get($(this).parent().data('value')));
		});

		$(".set-back").click(function() {
			$(".page-settings").css("pointer-events", "none").removeClass("animation");
			$(".page-settings").on('transitionend', function(evt) {
				if (evt.target !== this) {
					return;
				}
				$(".page-settings").remove();
			});
		});

		$(".set-option").click(function(evt) {
			var $this = $(this);
			var value = $this.data("value");
			if (value === "wallpaper") {
				openFile(function() {
					var file = this.files[0];
					var reader = new FileReader();
					reader.onload = function() {
						settings.set('wallpaper', this.result);
					};
					reader.readAsDataURL(file);
				});
			} else if (value === "logo") {
				openFile(function() {
					var file = this.files[0];
					var reader = new FileReader();
					reader.onload = function() {
						settings.set('logo', this.result);
					};
					reader.readAsDataURL(file);
				});
			} else if (value === "delLogo") {
				settings.set('wallpaper', '');
				settings.set('logo', '');
				settings.set('bookcolor', 'black');
				location.reload();
			} else if (value === "openurl") {
				open($this.find('.set-description').text());
			} else if (value === "export") {
				var oInput = $('<input>');
				oInput.val('{"bookMark":' + JSON.stringify(bookMark.getJson()) + '}');
				//oInput.val('{"bookMark":' + JSON.stringify(bookMark.getJson()) + ',"setData":' + JSON.stringify(settings.getJson()) + '}');
				document.body.appendChild(oInput[0]);
				console.log(store.get('bookMark'));
				oInput.select();
				document.execCommand("Copy");
				alert('已复制到剪贴板，请粘贴保存文件。');
				oInput.remove();
			} else if (value === "import") {
				var data = prompt("在这粘贴主页数据");
				try {
					data = JSON.parse(data);
					store.set("bookMark", data.bookMark);
					store.set("setData", data.setData);
					alert("导入成功!");
					location.reload();
				} catch (e) {
					alert("导入失败!");
				}
			} else if (evt.target.className !== 'set-select' && $this.find('.set-select')
				.length > 0) {
				$.fn.openSelect = function() {
					return this.each(function(idx, domEl) {
						if (document.createEvent) {
							var event = document.createEvent("MouseEvents");
							event.initMouseEvent("mousedown", true, true, window, 0,
								0, 0, 0, 0, false, false, false, false, 0, null);
							domEl.dispatchEvent(event);
						} else if (element.fireEvent) {
							domEl.fireEvent("onmousedown");
						}
					});
				}
				$this.find('.set-select').openSelect();
			} else if (evt.target.className !== 'set-checkbox' && $this.find('.set-checkbox')
				.length > 0) {
				$this.find('.set-checkbox').prop("checked", !$this.find('.set-checkbox').prop(
					"checked")).change();
			}
		});

		$(".set-select").change(function() {
			var dom = $(this),
				item = dom.parent().data("value"),
				value = dom.val();
			if (item === "engines" && value === "diy") {
				var engines = prompt("输入搜索引擎网址，（用“%s”代替搜索字词）");
				console.log(engines);
				if (engines) {
					settings.set('diyEngines', engines);
				} else {
					dom.val(settings.get('engines'));
					return false;
				}
			}
			// 保存设置
			settings.set(item, value);
		});

		$(".set-checkbox").change(function() {
			var dom = $(this),
				item = dom.parent().data("value"),
				value = dom.prop("checked");
			// 应用设置
			if (item === 'styleThin' && value === true) {
				$("body").addClass('styleThin');
			} else {
				$("body").removeClass('styleThin');
			}
			// 保存设置
			settings.set(item, value);
		});

	});

	// 下滑进入搜索
	require(['touchSwipe'], function() {
		$(".page-home").swipe({
			swipeStatus: function(event, phase, direction, distance, duration, fingerCount,
				fingerData) {
				if ($('.delbook').length !== 0) {
					return;
				}
				if (phase === 'start') {
					this.height = $(document).height();
				} else if (phase === 'move') {
					var sliding = Math.max(fingerData[0].end.y - fingerData[0].start.y, 0);
					$('.logo').attr("disabled", true).css({
						'opacity': 1 - (sliding / this.height) * 4,
						'transition-duration': '0ms'
					});
					$('.ornament-input-group').css({
						'transform': 'translate3d(0,' + Math.min((sliding / this
							.height) * 80, 30) + 'px,0)',
						'transition-duration': '0ms'
					});
					$('.bookmark').attr("disabled", true).css({
						'opacity': 1 - (sliding / this.height) * 4,
						'transform': 'scale(' + (1 - (sliding / this.height) * .3) +
							')',
						'transition-duration': '0ms'
					});
				} else if (phase === 'end' || phase === 'cancel') {
					$('.logo').removeAttr("disabled style");
					$('.bookmark').removeAttr("disabled style");
					if (distance >= 100 && direction === "down") {
						$('.ornament-input-group').css("transform", "").click();
						$('.logo,.bookmark,.anitInput').css('opacity', '0');
						$('.input-bg').css('border-color', 'var(--dark)');
						$('.logo,.bookmark').css('opacity', '');
					} else {
						$('.ornament-input-group').removeAttr("style");
					}
				}
			}
		});
	})

})